@@ -43,6 +43,10 @@ class Response(res):
         self._cached_text = None
         self._cached_json = None
 
+        self.cost_time = 0
+        self.retry_times = 0
+        self.request_kwargs = {}
+
         self._encoding = None
 
         self.encoding_errors = "strict"  # strict / replace / ignore
